package com.example.shawarma

import android.app.Application
import androidx.room.Room
import com.example.shawarma.data.api.MyServerService
import com.example.shawarma.data.api.repos.RestOrderProductRepository
import com.example.shawarma.data.api.repos.RestOrderRepository
import com.example.shawarma.data.api.repos.RestProductRepository
import com.example.shawarma.data.db.AppDatabase
import com.example.shawarma.data.repos.OrderProductRepository
import com.example.shawarma.data.repos.OrderRepository
import com.example.shawarma.data.repos.ProductRepository
import com.example.shawarma.data.repos.UserRepository
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.components.SingletonComponent
import javax.inject.Singleton
@Module
@InstallIn(SingletonComponent::class)
object AppModule {
    @Provides
    @Singleton
    fun provideDatabase(app: Application) :  AppDatabase {
        return Room.databaseBuilder(
            app,
            AppDatabase::class.java,
            AppDatabase.DB_NAME
        ).build()
    }

    @Provides
    @Singleton
    fun provideServerService() : MyServerService {
        return MyServerService.getInstance()
    }

    @Provides
    @Singleton
    fun provideUserRepository(service: MyServerService) : UserRepository {
        return UserRepository(service)
    }

    @Provides
    @Singleton
    fun provideProductRepository(db: AppDatabase, restProductRepository: RestProductRepository) : ProductRepository {
        return ProductRepository(database = db, db.productDao(), restProductRepository)
    }

    @Provides
    @Singleton
    fun provideRestProductRepository(service: MyServerService) : RestProductRepository {
        return RestProductRepository(service)
    }

    @Provides
    @Singleton
    fun provideOrderRepository(db: AppDatabase, restOrderRepository: RestOrderRepository) : OrderRepository {
        return OrderRepository(db, db.orderDao(), db.orderProductDao(), restOrderRepository)
    }

    @Provides
    @Singleton
    fun provideRestOrderRepository(service: MyServerService) : RestOrderRepository {
        return RestOrderRepository(service)
    }

    @Provides
    @Singleton
    fun provideOrderProductRepository(db: AppDatabase, restOrderProductRepository: RestOrderProductRepository) : OrderProductRepository {
        return OrderProductRepository(db.orderProductDao(), restOrderProductRepository)
    }

    @Provides
    @Singleton
    fun provideRestOrderProductRepository(service: MyServerService) : RestOrderProductRepository {
        return RestOrderProductRepository(service)
    }


}