package com.example.shawarma.data.api

import com.example.shawarma.data.api.models.OrderListResponse
import com.example.shawarma.data.api.models.OrderModelRemote
import com.example.shawarma.data.api.models.OrderProductRemote
import com.example.shawarma.data.api.models.ProductListResponse
import com.example.shawarma.data.api.models.ProductModelRemote
import com.example.shawarma.data.api.models.TokenModelRemote
import com.example.shawarma.data.api.models.UserModelRemote
import com.jakewharton.retrofit2.converter.kotlinx.serialization.asConverterFactory
import kotlinx.serialization.json.Json
import okhttp3.MediaType.Companion.toMediaType
import okhttp3.logging.HttpLoggingInterceptor
import retrofit2.Retrofit
import retrofit2.http.Body
import retrofit2.http.DELETE
import retrofit2.http.GET
import retrofit2.http.Header
import retrofit2.http.POST
import retrofit2.http.PUT
import retrofit2.http.Path
import retrofit2.http.Query


interface MyServerService {
    //
    // USER
    //
    @POST("register")
    suspend fun createUser(
        @Body user: UserModelRemote,
    ): UserModelRemote

    @POST("auth")
    suspend fun getToken(
        @Body user: UserModelRemote
    ) : TokenModelRemote

    @POST("check/login")
    suspend fun checkLogin(
        @Body user: UserModelRemote
    ) :UserModelRemote?


    //
    // PRODUCTS
    //

    @GET("user/products/{after}")
    suspend fun getProductsList(@Path("after") after: Int, @Header("Authorization") token: String) : ProductListResponse

    @GET("user/discounts/{after}")
    suspend fun getDiscountsList(@Path("after") after: Int, @Header("Authorization") token: String) : ProductListResponse

    @GET("user/items/{after}")
    suspend fun getItemsList(@Path("after") after: Int, @Header("Authorization") token: String) : ProductListResponse

    @POST("product")
    suspend fun insertProduct(
        @Body product: ProductModelRemote,
        @Header("Authorization") token: String
    ) : ProductModelRemote

    @PUT("product")
    suspend fun updateProduct(
        @Body product: ProductModelRemote,
        @Header("Authorization") token: String
    ): ProductModelRemote

    @DELETE("product/{id}")
    suspend fun deleteProduct(@Path("id") id: Int, @Header("Authorization") token: String)

    //
    // ORDERS
    //

    @GET("order/unpaid")
    suspend fun getUnpaidOrder(@Header("Authorization") token: String) : OrderModelRemote

    @GET("order/paid/{after}")
    suspend fun getPaidOrdersList(@Path("after") after: Int, @Header("Authorization") token: String) : OrderListResponse

    @GET("order/all_paid/{after}")
    suspend fun getAllPaidOrdersList(@Path("after") after: Int, @Header("Authorization") token: String) : OrderListResponse

    @GET("order/all_ready/{after}")
    suspend fun getAllReadyOrdersList(@Path("after") after: Int, @Header("Authorization") token: String) : OrderListResponse

    @GET("order/all_served/{after}")
    suspend fun getAllServedOrdersList(@Path("after") after: Int, @Header("Authorization") token: String) : OrderListResponse

    @POST("order")
    suspend fun insertOrder(@Body order: OrderModelRemote, @Header("Authorization") token: String) : OrderModelRemote?

    @PUT("order")
    suspend fun updateOrder(@Body order: OrderModelRemote, @Header("Authorization") token: String) : OrderModelRemote?

    @DELETE("order/{id}")
    suspend fun deleteOrder(@Path("id") id: Int, @Header("Authorization") token: String)

    //
    // ORDER PRODUCTS
    //

    @POST("order/product")
    suspend fun insertOrderProduct(@Body orderProduct: OrderProductRemote, @Header("Authorization") token: String)

    @PUT("order/product")
    suspend fun updateOrderProduct(@Body orderProduct: OrderProductRemote, @Header("Authorization") token: String)

    @POST("order/product/delete")
    suspend fun deleteOrderProduct(@Body orderProduct: OrderProductRemote, @Header("Authorization") token: String)

    //
    // COURSEWORK ANALYSIS
    //

    @GET("analysis/products")
    suspend fun getTopProducts(@Query("period") period : String, @Header("Authorization") token: String) : List<ProductModelRemote>


    companion object {
        private const val BASE_URL = "https://10.0.2.2:80/api/"

        @Volatile
        private var INSTANCE: MyServerService? = null

        fun getInstance(): MyServerService {
            return INSTANCE ?: synchronized(this) {
                val logger = HttpLoggingInterceptor()
                logger.level = HttpLoggingInterceptor.Level.BASIC
                val client = OkHttpClientSettings.getUnsafeOkHttpClient()
                return Retrofit.Builder()
                    .baseUrl(BASE_URL)
                    .client(client)
                    .addConverterFactory(Json.asConverterFactory("application/json".toMediaType()))
                    .build()
                    .create(MyServerService::class.java)
                    .also { INSTANCE = it }
            }
        }
    }
}