package com.example.shawarma.data.db.dao

import androidx.paging.PagingSource
import androidx.room.Dao
import androidx.room.Delete
import androidx.room.Insert
import androidx.room.OnConflictStrategy.Companion.REPLACE
import androidx.room.Query
import androidx.room.Update
import com.example.shawarma.data.db.models.OrderModel
import com.example.shawarma.data.db.models.OrderWithProducts
import kotlinx.coroutines.flow.Flow
@Dao
interface OrderDao {
    @Insert(onConflict = REPLACE)
    suspend fun insert(order: OrderModel) : Long
    @Update
    suspend fun update(order: OrderModel)
    @Delete
    suspend fun delete(order: OrderModel)
    @Query("select * from orders")
    fun getAll(): Flow<List<OrderWithProducts>>
    @Query("select * from orders where orders.id =:id")
    fun getById(id: Int): Flow<OrderWithProducts?>
    @Query("select * from orders where orders.user_id =:userId")
    fun getByUserId(userId: Int): Flow<List<OrderWithProducts>>
    @Query("select * from orders where orders.user_id =:userId and orders.order_status = 'Неоплачено'")
    fun getUnpaidByUser(userId: Int) : Flow<OrderWithProducts>
    @Query("select * from orders where orders.user_id =:userId and (orders.order_status = 'Готовится' or orders.order_status = 'Готово')")
    fun getPaidByUser(userId: Int) : Flow<List<OrderWithProducts>>

    suspend fun insertAll(orders: List<OrderModel>) {
        for (order in orders) {
            insert(order)
        }
    }

    @Query("select * from orders where orders.order_status = 'Готовится' or orders.order_status = 'Готово'")
    fun getPaidPaged(): PagingSource<Int, OrderWithProducts>

    @Query("select * from orders where orders.order_status = 'Готовится'")
    fun getAllPaid(): PagingSource<Int, OrderWithProducts>

    @Query("select * from orders where orders.order_status = 'Готово'")
    fun getAllReady(): PagingSource<Int, OrderWithProducts>

    @Query("select * from orders where orders.order_status = 'Выдано'")
    fun getAllServed(): PagingSource<Int, OrderWithProducts>

    @Query("delete from orders where orders.order_status = 'Готовится'")
    fun deleteAllPaid()

    @Query("delete from orders where orders.order_status = 'Готово'")
    fun deleteAllReady()
    @Query("delete from orders where orders.order_status = 'Выдано'")
    fun deleteAllServed()

    fun deleteByQuery(query: String) {
        if (query == "paid" || query == "all_paid") {
            deleteAllPaid()
        }
        if (query == "all_ready") {
            deleteAllReady()
        }
        if (query == "all_served") {
            deleteAllServed()
        }
    }
}