package com.example.shawarma.data.db.dao

import androidx.paging.PagingSource
import androidx.room.Dao
import androidx.room.Delete
import androidx.room.Insert
import androidx.room.OnConflictStrategy.Companion.REPLACE
import androidx.room.Query
import androidx.room.Update
import com.example.shawarma.data.db.models.ProductModel
import kotlinx.coroutines.flow.Flow

@Dao
interface ProductDao {
    @Insert(onConflict = REPLACE)
    suspend fun insert(product: ProductModel)

    suspend fun insertAll(products: List<ProductModel>) {
        for (product in products) {
            insert(product)
        }
    }

    @Update
    suspend fun update(product: ProductModel)

    @Delete()
    suspend fun delete(product: ProductModel)

    @Query("select * from products where products.product_old_price is null")
    fun getAll() : Flow<List<ProductModel>>

    @Query("select * from products where products.product_old_price is not null")
    fun getDiscounts() : Flow<List<ProductModel>>

    @Query("select * from products")
    fun getItems() : Flow<List<ProductModel>>

    @Query("select * from products where products.id = :id")
    fun getById(id: Int): Flow<ProductModel>

    @Query("select * from products where products.product_old_price is null")
    fun getPaged(): PagingSource<Int, ProductModel>

    @Query("select * from products where products.product_old_price is not null")
    fun getPagedDiscounts(): PagingSource<Int, ProductModel>

    @Query("select * from products")
    fun getPagedItems(): PagingSource<Int, ProductModel>

    @Query("select * from products where products.id > :loadKey limit 20")
    fun getItemsByLoadKey(loadKey: Int): Flow<List<ProductModel>>

    @Query("delete from products where products.product_old_price is null")
    fun deleteAllProducts()

    @Query("delete from products where products.product_old_price is not null")
    fun deleteAllDiscountProducts()

    @Query("delete from products")
    fun deleteAllItems()

    fun deleteByQuery(query: String) {
        if (query == "home") {
            deleteAllProducts()
        }
        if (query == "discounts") {
            deleteAllDiscountProducts()
        }
        if (query == "items") {
            deleteAllItems()
        }
    }
}