package com.example.shawarma.data.repos

import androidx.paging.ExperimentalPagingApi
import androidx.paging.Pager
import androidx.paging.PagingConfig
import androidx.paging.PagingData
import com.example.shawarma.data.api.MyServerService
import com.example.shawarma.data.api.mediators.ProductRemoteMediator
import com.example.shawarma.data.api.models.ProductModelRemote
import com.example.shawarma.data.api.repos.RestProductRepository
import com.example.shawarma.data.db.AppDatabase
import com.example.shawarma.data.db.dao.ProductDao
import com.example.shawarma.data.db.models.ProductModel
import kotlinx.coroutines.flow.Flow
import javax.inject.Inject

class ProductRepository @Inject constructor(
    private val database: AppDatabase,
    private val productDao: ProductDao,
    private val restRepository: RestProductRepository
) {
    suspend fun insert(product: ProductModel, token: String) {
        return restRepository.insert(product, token)
    }
    suspend fun update(product: ProductModel, token: String) {
        return restRepository.update(product, token)
    }
    suspend fun delete(product: ProductModel, token: String) {
        productDao.delete(product)
        return restRepository.delete(product.id!!, token)
    }
    fun getById(id: Int): Flow<ProductModel> {
        return productDao.getById(id)
    }
    @OptIn(ExperimentalPagingApi::class)
    fun getAllProductsPaged(token: String): Flow<PagingData<ProductModel>> = Pager(
        config = PagingConfig(
            pageSize = 6,
            enablePlaceholders = false
        ),
        pagingSourceFactory = productDao::getPaged,
        remoteMediator = ProductRemoteMediator(database = database, serverService = MyServerService.getInstance(), query = "home", token = token)
    ).flow

    @OptIn(ExperimentalPagingApi::class)
    fun getAllDiscountsPaged(token: String): Flow<PagingData<ProductModel>> = Pager(
        config = PagingConfig(
            pageSize = 6,
            enablePlaceholders = false
        ),
        pagingSourceFactory = productDao::getPagedDiscounts,
        remoteMediator = ProductRemoteMediator(database = database, serverService = MyServerService.getInstance(), query = "discounts", token = token)
    ).flow

    @OptIn(ExperimentalPagingApi::class)
    fun getAllItemsPaged(token: String): Flow<PagingData<ProductModel>> = Pager(
        config = PagingConfig(
            pageSize = 6,
            enablePlaceholders = false
        ),
        pagingSourceFactory = productDao::getPagedItems,
        remoteMediator = ProductRemoteMediator(database = database, serverService = MyServerService.getInstance(), query = "items", token = token)
    ).flow

    suspend fun getTopProducts(period: String, token: String) : List<ProductModelRemote> {
        return restRepository.getTopProducts(period, token)
    }

}