package com.example.shawarma.ui.screens.discount

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.Button
import androidx.compose.material.ButtonDefaults
import androidx.compose.material.Card
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextDecoration
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.zIndex
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.paging.compose.collectAsLazyPagingItems
import com.example.shawarma.R
import com.example.shawarma.data.db.models.ProductModel
import com.example.shawarma.data.sharedpref.PreferencesManager
import com.example.shawarma.ui.theme.MarckFamily
import com.example.shawarma.ui.theme.MyLightYellow
import com.example.shawarma.ui.theme.MyMainBackground
import com.example.shawarma.ui.theme.MyOrange
import com.example.shawarma.ui.theme.MyPriceBackground
import com.example.shawarma.ui.theme.NunitoFamily
import com.example.shawarma.viewmodels.HomeViewModel
import com.example.shawarma.ui.widgets.ShawarmaLogo2

@Composable
fun DiscountScreen() {
        Box(
            contentAlignment = Alignment.TopCenter
        ) {
            DiscountList()
            ShawarmaLogo2()
        }

}

@Composable
fun DiscountList(){
    val preferencesManager = PreferencesManager(LocalContext.current)
    val searchToken = preferencesManager.getData("token", "")

    val homeViewModel: HomeViewModel = hiltViewModel<HomeViewModel>()


    val productsListUiState = homeViewModel.getDiscountList(searchToken).collectAsLazyPagingItems()

    Box(
        modifier = Modifier
            .clip(shape = RoundedCornerShape(30.dp))
            .padding(top = 100.dp)
            .fillMaxSize()
            .background(color = MyMainBackground)
            .zIndex(2f),

        contentAlignment = Alignment.TopCenter
    ){
        Text(
            text = "Акции",
            fontFamily = MarckFamily,
            fontSize = 40.sp,
            modifier = Modifier.padding(top = 15.dp)
        )
        LazyColumn(
            horizontalAlignment = Alignment.CenterHorizontally,
            modifier = Modifier.padding(top = 80.dp)
        )
        {
            items(productsListUiState.itemCount) { index ->
                if (index % 2 == 0 && index == productsListUiState.itemCount - 1) {
                    Row(
                        horizontalArrangement = Arrangement.SpaceAround,
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(top = 10.dp)
                    ) {
                        DiscountCard(productsListUiState[index]!!)
                    }
                } else {
                    if (index % 2 != 1) {
                        Row(
                            horizontalArrangement = Arrangement.SpaceAround,
                            modifier = Modifier
                                .fillMaxWidth()
                                .padding(top = 10.dp)
                        ) {
                            DiscountCard(productsListUiState[index]!!)
                            DiscountCard(productsListUiState[index+1]!!)
                        }
                    }
                }
                if (index == productsListUiState.itemCount - 1) {
                    Spacer(modifier = Modifier.height(70.dp))
                }
            }
        }
    }
}

@Composable
fun DiscountCard(product : ProductModel){
    val homeViewModel: HomeViewModel = hiltViewModel<HomeViewModel>()
    val preferencesManager = PreferencesManager(LocalContext.current)
    Card(
        shape = RoundedCornerShape(20.dp),
        backgroundColor = Color.White,
        border = BorderStroke(2.dp, MyOrange),
        modifier = Modifier
            .size(160.dp)
    ) {
        Column(
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Text(
                text = product.title,
                fontFamily = NunitoFamily,
                fontSize =  20.sp,
                fontWeight = FontWeight.Bold,
                modifier = Modifier.padding(top = 10.dp),
                maxLines = 1,
                softWrap = true,
                overflow = TextOverflow.Ellipsis
            )
            Image(
                painter = painterResource(id = R.drawable.shawarma2),
                contentDescription = "Shawarma",
                Modifier.size(135.dp, 70.dp)
            )
            Spacer(modifier = Modifier.height(16.dp))
            Card(
                shape = RoundedCornerShape(20.dp),
                backgroundColor = MyPriceBackground,
                border = BorderStroke(2.dp, MyOrange),
                modifier = Modifier
                    .size(160.dp, 36.dp)
            ) {
                Row(
                    horizontalArrangement = Arrangement.SpaceBetween
                ){
                    Box(
                        modifier = Modifier.padding(start = 12.dp)
                    ) {
                        Text(
                            text = product.oldPrice.toString() + "руб. ",
                            fontFamily = NunitoFamily,
                            fontSize =  10.sp,
                            fontWeight = FontWeight.Bold,
                            textDecoration = TextDecoration.LineThrough
                        )
                        Text(
                            text = product.price.toString() + "руб. ",
                            fontFamily = NunitoFamily,
                            fontSize =  16.sp,
                            fontWeight = FontWeight.ExtraBold,
                            color = Color.Red,
                            modifier = Modifier.padding(top = 8.dp)
                        )
                    }

                    Button(
                        onClick = {
                            product.id?.let { homeViewModel.addProductToCart(it, preferencesManager.getData("token", "null")) }
                        },
                        colors = ButtonDefaults.buttonColors(
                            backgroundColor = MyLightYellow,
                            contentColor = Color.Black
                        ),
                        shape = RoundedCornerShape(20.dp),
                    ) {
                        Text(
                            text = "Купить",
                            fontSize = 14.sp,
                            fontWeight = FontWeight.ExtraBold,
                            fontFamily = NunitoFamily,
                        )
                    }
                }
            }
        }
    }
}