package com.example.shawarma.ui.screens.products

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.Button
import androidx.compose.material.ButtonDefaults
import androidx.compose.material.Card
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.livedata.observeAsState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.zIndex
import androidx.hilt.navigation.compose.hiltViewModel
import com.example.shawarma.data.api.models.ProductModelRemote
import com.example.shawarma.data.sharedpref.PreferencesManager
import com.example.shawarma.ui.theme.MarckFamily
import com.example.shawarma.ui.theme.MyLightYellow
import com.example.shawarma.ui.theme.MyMainBackground
import com.example.shawarma.ui.theme.MyOrange
import com.example.shawarma.ui.theme.NunitoFamily
import com.example.shawarma.viewmodels.ProductsViewModel
import com.example.shawarma.ui.widgets.ShawarmaLogo2

@Composable
fun ProductsAnalysis() {
    val productsViewModel: ProductsViewModel = hiltViewModel<ProductsViewModel>()
    Box(
        contentAlignment = Alignment.TopCenter
    ) {
        TopProductsWidget(productsViewModel)
        ShawarmaLogo2()
    }
}

@Composable
fun TopProductsWidget(productsViewModel: ProductsViewModel) {
    val preferencesManager = PreferencesManager(LocalContext.current)
    val searchToken = preferencesManager.getData("token", "")
    val topProductsList = productsViewModel.topProductList.observeAsState().value

    Box(
        modifier = Modifier
            .clip(shape = RoundedCornerShape(30.dp))
            .padding(top = 100.dp)
            .fillMaxSize()
            .background(color = MyMainBackground)
            .zIndex(2f),

        contentAlignment = Alignment.TopCenter
    ){
        Text(
            text = "Аналитика",
            fontFamily = MarckFamily,
            fontSize = 40.sp,
            modifier = Modifier.padding(top = 15.dp)
        )
        Text(text = "Топ-10 продуктов за:", modifier = Modifier.padding(top = 60.dp))
        Row(
            modifier = Modifier
                .fillMaxHeight()
                .padding(top = 80.dp)
        ){
            Button(
                modifier = Modifier
                    .fillMaxWidth(0.33f)
                    .weight(1f),
                colors = ButtonDefaults.buttonColors(
                    backgroundColor = MyLightYellow
                ),
                border = BorderStroke(2.dp, color = MyOrange),
                shape = RoundedCornerShape(20.dp),
                onClick = {
                    productsViewModel.getTopProductsList(searchToken, "week")
                }
            ) {
                Text(text = "Неделя")
            }
            Button(
                modifier = Modifier
                    .fillMaxWidth(0.33f)
                    .weight(1f),
                colors = ButtonDefaults.buttonColors(
                    backgroundColor = MyLightYellow
                ),
                border = BorderStroke(2.dp, color = MyOrange),
                shape = RoundedCornerShape(20.dp),
                onClick = {
                    productsViewModel.getTopProductsList(searchToken, "month")
                }
            ) {
                Text(text = "Месяц")
            }
            Button(
                modifier = Modifier
                    .fillMaxWidth(0.33f)
                    .weight(1f),
                colors = ButtonDefaults.buttonColors(
                    backgroundColor = MyLightYellow
                ),
                border = BorderStroke(2.dp, color = MyOrange),
                shape = RoundedCornerShape(20.dp),
                onClick = {
                    productsViewModel.getTopProductsList(searchToken, "year")
                }
            ) {
                Text(text = "Год")
            }
        }
        if (!topProductsList.isNullOrEmpty()) {
            LazyColumn(
                modifier = Modifier.padding(top = 140.dp, bottom = 60.dp),

            ){
                items(
                    topProductsList.size
                ) {
                    TopProductItem(topProductsList[it], it)
                    Spacer(modifier = Modifier.size(20.dp))
                }
            }
        }
    }
}

@Composable
fun TopProductItem(product: ProductModelRemote, index: Int){
    Card(
        border = BorderStroke(width = 2.dp, color = MyOrange),
        shape = RoundedCornerShape(size = 20.dp),
        backgroundColor = Color.White,
        modifier = Modifier.size(340.dp, 100.dp)
    ) {
        Row(
            modifier = Modifier
                .padding(20.dp),
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceAround
        ) {
            Column(
                modifier = Modifier.fillMaxWidth(0.5f)
            ) {
                Text(
                    text = (index + 1).toString() + ". " + product.title,
                    fontFamily = NunitoFamily,
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold,
                    maxLines = 1,
                    overflow = TextOverflow.Ellipsis
                )
                if (product.old_price != null) {
                    Text(
                        text = product.price.toString() + " руб.",
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold,
                        color = Color.Red
                    )
                }
                else {
                    Text(
                        text = product.price.toString() + " руб.",
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                }

            }
            Column(
                modifier = Modifier.fillMaxWidth(0.5f)
            ) {
                Text(
                    text = "Покупок:",
                    fontFamily = NunitoFamily,
                    fontSize = 16.sp,
                    fontWeight = FontWeight.Bold,
                    maxLines = 1,
                    overflow = TextOverflow.Ellipsis
                )
                Text(
                    text = product.purchase_count.toString(),
                    fontFamily = NunitoFamily,
                    fontSize = 16.sp,
                    fontWeight = FontWeight.Bold,
                    maxLines = 1,
                    overflow = TextOverflow.Ellipsis
                )
            }
        }
    }
}