package com.example.shawarma.viewmodels

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.paging.PagingData
import com.example.shawarma.data.db.models.OrderStatus
import com.example.shawarma.data.db.models.OrderWithProducts
import com.example.shawarma.data.repos.OrderProductRepository
import com.example.shawarma.data.repos.OrderRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class CartViewModel @Inject constructor(
    private val orderRepository: OrderRepository,
    private val orderProductRepository: OrderProductRepository
) : ViewModel(){
    private val _unpaidOrder = MutableLiveData<OrderWithProducts>()
    val unpaidOrder: LiveData<OrderWithProducts>
        get() = _unpaidOrder


    fun getOrders(token: String) {
        viewModelScope.launch {
            _unpaidOrder.postValue(orderRepository.getUnpaidByUser(token))
        }
    }

    fun getPaidList(token: String) : Flow<PagingData<OrderWithProducts>> {
        return orderRepository.getPaidPaged(token)
    }

    fun payForOrder(token: String, order: OrderWithProducts) {
        if (order.orderWithProducts.isEmpty()) {
            return
        }
        val model = order.order
        model.status = OrderStatus.Готовится.name
        viewModelScope.launch {
            orderRepository.update(token, model)
        }
        _unpaidOrder.postValue(null)
    }

    fun removeProductFromOrder(token: String, order: OrderWithProducts, productId: Int) {
        val model = order.orderWithProducts[productId].orderProductModel
        if(model.quantity == 1) {
            // delete
            viewModelScope.launch {
                orderProductRepository.delete(token, model)
            }
            getOrders(token)
        }
        else{
            // update
            model.quantity -= 1
            viewModelScope.launch {
                orderProductRepository.update(token, model)
            }
        }
    }
    fun addProductToOrder(token: String, order: OrderWithProducts, productId: Int) {
        val model = order.orderWithProducts[productId].orderProductModel
        // update
        model.quantity += 1
        viewModelScope.launch {
            orderProductRepository.update(token, model)
        }

    }
}