package com.example.shawarma.viewmodels

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.paging.PagingData
import com.example.shawarma.data.db.models.OrderModel
import com.example.shawarma.data.db.models.OrderProductModel
import com.example.shawarma.data.db.models.OrderStatus
import com.example.shawarma.data.db.models.ProductModel
import com.example.shawarma.data.repos.OrderProductRepository
import com.example.shawarma.data.repos.OrderRepository
import com.example.shawarma.data.repos.ProductRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.first
import kotlinx.coroutines.launch
import java.util.Calendar
import java.util.Date
import javax.inject.Inject

@HiltViewModel
class HomeViewModel @Inject constructor(
    private val productRepository: ProductRepository,
    private val orderRepository: OrderRepository,
    private val orderProductRepository: OrderProductRepository
) : ViewModel() {

    fun getProductList(token:String): Flow<PagingData<ProductModel>> {
        return productRepository.getAllProductsPaged(token)
    }

    fun getDiscountList(token: String): Flow<PagingData<ProductModel>> {
        return productRepository.getAllDiscountsPaged(token)
    }


    fun addProductToCart(productId: Int, token: String) {
        viewModelScope.launch {
            val product = productRepository.getById(productId).first()
            val order = orderRepository.getUnpaidByUser(token)
            if (order == null) {
                val calendar: Calendar = Calendar.getInstance()
                calendar.time = Date()
                calendar.add(Calendar.HOUR_OF_DAY, 4)
                val newOrder = orderRepository.insert(token, OrderModel(null, OrderStatus.Неоплачено.name, null, calendar.time.toString()))
                if (newOrder != null) {
                    orderProductRepository.insert(token, OrderProductModel(newOrder.id!!, productId, 1, product.price))
                }
            }
            else {
                var isAlreadyAdded = false
                for (prod in order.orderWithProducts) {
                    if (prod.product != null) {
                        if (prod.product!!.id == productId) {
                            val model = prod.orderProductModel
                            model.quantity += 1
                            model.totalPrice += prod.product!!.price
                            orderProductRepository.update(token, model)
                            isAlreadyAdded = true
                        }
                    }
                }
                if (!isAlreadyAdded) {
                    orderProductRepository.insert(token, OrderProductModel(order.order.id!!, productId, 1, product.price))
                }
            }
        }
    }
}