package com.example.shawarma.viewmodels

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.paging.PagingData
import com.example.shawarma.data.db.models.OrderWithProducts
import com.example.shawarma.data.repos.OrderRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class OrdersViewModel @Inject constructor(
    private val orderRepository: OrderRepository
) : ViewModel() {

    fun getAllPaidList(token: String) : Flow<PagingData<OrderWithProducts>> {
        return orderRepository.getAllPaidPaged(token)
    }

    fun getAllReadyList(token: String) : Flow<PagingData<OrderWithProducts>> {
        return orderRepository.getAllReadyPaged(token)
    }

    fun getAllServedList(token: String) : Flow<PagingData<OrderWithProducts>> {
        return orderRepository.getAllServedPaged(token)
    }

    fun changeOrderStatus(token: String, order: OrderWithProducts, newStatus: String) {
        val model = order.order
        model.status = newStatus

        viewModelScope.launch{
            orderRepository.update(token, model)
        }
    }

    fun deleteOrder(token: String, order: OrderWithProducts) {
        viewModelScope.launch{
            orderRepository.delete(token, order.order)
        }
    }


}