package com.example.shawarma.viewmodels

import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.paging.PagingData
import com.example.shawarma.data.api.models.ProductModelRemote
import com.example.shawarma.data.db.models.ProductModel
import com.example.shawarma.data.repos.ProductRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class ProductsViewModel  @Inject constructor(
    private val productRepository: ProductRepository
) : ViewModel() {

    fun getItemsList(token:String): Flow<PagingData<ProductModel>> {
        return productRepository.getAllItemsPaged(token)
    }

    fun deleteProduct(product: ProductModel, token: String) {
        viewModelScope.launch {
            productRepository.delete(product, token)
        }
    }

    val topProductList = MutableLiveData<List<ProductModelRemote>?>(null)

    fun getTopProductsList(token: String, period: String) {
        viewModelScope.launch {
            topProductList.postValue(productRepository.getTopProducts(period, token))
        }
    }


}